<?php

App::uses('EvTransactionsAppModel', 'EvTransactions.Model');

class Transaction extends EvTransactionsAppModel {

	/**
	 * Display field
	 *
	 * @var string
	 */
	public $displayField = 'id';

	public $hasMany = array(
		'TransactionsItem' => array(
			'className' => 'EvTransactions.TransactionsItem'
		)
	);

	/**
	 * redefiune the model constructor so we can setup the dynamic relationship
	 */
	public function __construct($id = false, $table = null, $ds = null) {
		parent::__construct($id, $table, $ds);

		// setup dynamic relation
		$relationships = Configure::read('EvTransactions.transactionRelation');
		if (! empty($relationships)) {
			$belongsTo = array();
			foreach ($relationships as $key => $value) {
				$belongsTo[$key] = $value;
			}

			if (! empty($belongsTo)) {
				$this->bindModel(
					array(
						'belongsTo' => $belongsTo
					),
					false
				);
			}
		}
	}

	/**
	 * return the array to use for retrieving transaction listing
	 *
	 * @param int user_id we are pulling transactions for
	 * @param int|false int to limit number of rows or false to return all rows
	 * @return array array of data for paginate function / model->find
	 */
	public function transactionListParams($userId, $limit = false) {
		$contain = Configure::read('EvTransactions.listing.contain');
		$contain = array_merge(array('TransactionsItem'), $contain);

		$return = array(
			'contain' => $contain,
			'conditions' => array(
				'Transaction.user_id' => $userId
			),
			'order' => 'Transaction.id DESC'
		);

		if ($limit !== false) {
			$return['limit'] = $limit;
		}

		return $return;
	}

}
